" Vim syntax file
""""
"  CLRadeonExtender - Unofficial OpenCL Radeon Extensions Library
"  Copyright (C) 2014-2018 Mateusz Szpakowski
"
"  This library is free software; you can redistribute it and/or
"  modify it under the terms of the GNU Lesser General Public
"  License as published by the Free Software Foundation; either
"  version 2.1 of the License, or (at your option) any later version.
"
"  This library is distributed in the hope that it will be useful,
"  but WITHOUT ANY WARRANTY; without even the implied warranty of
"  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
"  Lesser General Public License for more details.
"
"  You should have received a copy of the GNU Lesser General Public
"  License along with this library; if not, write to the Free Software
"  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

" Language: CLRadeonExtender
" Maintainer: Mateusz Szpakowski <matszpk@interia.pl>
""""

" Quit when a (custom) syntax file was already loaded
if exists("b:current_syntax")
  finish
endif

" pseudo-ops are case-insensitive
syntax case ignore

" storing cpoptions
let s:cpo_save = &cpo
set cpo&vim

" variables

syntax match asmVar "[A-Za-z.$_][0-9A-Za-z.$_]*"

" constants

syntax match asmInteger "[1-9]\d*"
syntax match asmInteger "0\o\+"
syntax match asmInteger "0[xX]\x\+"
syntax match asmInteger "0[bB][01]\+"
syntax match asmFloat "[\-+]\?\d\+\.\d*\([Ee][-+]\?\d\+\)\?[sShHlL]\?"
syntax match asmFloat "[\-+]\?\.\d\+\([Ee][-+]\?\d\+\)\?[sShHlL]\?"
syntax match asmFloat "[\-+]\?\d\+[Ee][-+]\?\d\+[sShHlL]\?"
syntax match asmFloat "[\-+]\?0[Xx]\x\+\.\x*\([Pp][-+]\?\d\+\)\?[sShHlL]\?"
syntax match asmFloat "[\-+]\?0[Xx]\.\x*\([Pp][-+]\?\d\+\)\?[sShHlL]\?"
syntax match asmFloat "[\-+]\?0[Xx]\x\+[Pp][-+]\?\d\+[sShHlL]\?"
syntax match asmChar "'\([^'\\]\|\\'\|\\\)*'"
syntax match asmString '"\([^"\\]\|\\"\|\\\)*"'

" operators

syntax match asmOperator "[+\-*/%&|\^~!<>?:]"
syntax match asmOperator "//"
syntax match asmOperator "%%"
syntax match asmOperator "<<"
syntax match asmOperator ">>"
syntax match asmOperator "<<<"
syntax match asmOperator ">>>"
syntax match asmOperator "&&"
syntax match asmOperator "||"
syntax match asmOperator "=="
syntax match asmOperator "!="
syntax match asmOperator "<>"
syntax match asmOperator "<="
syntax match asmOperator ">="

" comments

syn keyword asmTodo     contained TODO

syntax region asmComment start="/\*" end="\*/" contains=asmTodo
syntax match asmComment "#.*$"

" other pseudo-ops
syntax match asmPseudoOps "\.32bit"
syntax match asmPseudoOps "\.64bit"
syntax match asmPseudoOps "\.abort"
syntax match asmPseudoOps "\.acl_version"
syntax match asmPseudoOps "\.align"
syntax match asmPseudoOps "\.altmacro"
syntax match asmPseudoOps "\.amd"
syntax match asmPseudoOps "\.amdcl2"
syntax match asmPseudoOps "\.arch"
syntax match asmPseudoOps "\.arch_minor"
syntax match asmPseudoOps "\.arch_stepping"
syntax match asmPseudoOps "\.arg"
syntax match asmPseudoOps "\.args"
syntax match asmPseudoOps "\.ascii"
syntax match asmPseudoOps "\.asciz"
syntax match asmPseudoOps "\.balign"
syntax match asmPseudoOps "\.balignl"
syntax match asmPseudoOps "\.balignw"
syntax match asmPseudoOps "\.boolconsts"
syntax match asmPseudoOps "\.bssdata"
syntax match asmPseudoOps "\.buggyfplit"
syntax match asmPseudoOps "\.byte"
syntax match asmPseudoOps "\.call_convention"
syntax match asmPseudoOps "\.calnote"
syntax match asmPseudoOps "\.cbid"
syntax match asmPseudoOps "\.cbmask"
syntax match asmPseudoOps "\.cf_call"
syntax match asmPseudoOps "\.cf_cjump"
syntax match asmPseudoOps "\.cf_end"
syntax match asmPseudoOps "\.cf_jump"
syntax match asmPseudoOps "\.cf_ret"
syntax match asmPseudoOps "\.cf_start"
syntax match asmPseudoOps "\.codeversion"
syntax match asmPseudoOps "\.compile_options"
syntax match asmPseudoOps "\.condout"
syntax match asmPseudoOps "\.config"
syntax match asmPseudoOps "\.constantbuffers"
syntax match asmPseudoOps "\.control_directive"
syntax match asmPseudoOps "\.cws"
syntax match asmPseudoOps "\.data"
syntax match asmPseudoOps "\.debug_private_segment_buffer_sgpr"
syntax match asmPseudoOps "\.debug_wavefront_private_segment_offset_sgpr"
syntax match asmPseudoOps "\.debugmode"
syntax match asmPseudoOps "\.default_hsa_features"
syntax match asmPseudoOps "\.dims"
syntax match asmPseudoOps "\.double"
syntax match asmPseudoOps "\.driver_info"
syntax match asmPseudoOps "\.driver_version"
syntax match asmPseudoOps "\.dx10clamp"
syntax match asmPseudoOps "\.eflags"
syntax match asmPseudoOps "\.earlyexit"
syntax match asmPseudoOps "\.endr"
syntax match asmPseudoOps "\.endrept"
syntax match asmPseudoOps "\.ends"
syntax match asmPseudoOps "\.endscope"
syntax match asmPseudoOps "\.end"
syntax match asmPseudoOps "\.entry"
syntax match asmPseudoOps "\.enum"
syntax match asmPseudoOps "\.equ"
syntax match asmPseudoOps "\.equiv"
syntax match asmPseudoOps "\.eqv"
syntax match asmPseudoOps "\.err"
syntax match asmPseudoOps "\.error"
syntax match asmPseudoOps "\.exceptions"
syntax match asmPseudoOps "\.exitm"
syntax match asmPseudoOps "\.extern"
syntax match asmPseudoOps "\.fail"
syntax match asmPseudoOps "\.file"
syntax match asmPseudoOps "\.fill"
syntax match asmPseudoOps "\.fillq"
syntax match asmPseudoOps "\.fixed_work_group_size"
syntax match asmPseudoOps "\.fkernel"
syntax match asmPseudoOps "\.float"
syntax match asmPseudoOps "\.floatconsts"
syntax match asmPseudoOps "\.floatmode"
syntax match asmPseudoOps "\.for"
syntax match asmPseudoOps "\.format"
syntax match asmPseudoOps "\.gallium"
syntax match asmPseudoOps "\.gds_segment_size"
syntax match asmPseudoOps "\.gdssize"
syntax match asmPseudoOps "\.get_driver_version"
syntax match asmPseudoOps "\.get_llvm_version"
syntax match asmPseudoOps "\.get_arch"
syntax match asmPseudoOps "\.get_64bit"
syntax match asmPseudoOps "\.get_gpu"
syntax match asmPseudoOps "\.get_format"
syntax match asmPseudoOps "\.get_policy"
syntax match asmPseudoOps "\.global"
syntax match asmPseudoOps "\.globalbuffers"
syntax match asmPseudoOps "\.globaldata"
syntax match asmPseudoOps "\.globl"
syntax match asmPseudoOps "\.gotsym"
syntax match asmPseudoOps "\.gpu"
syntax match asmPseudoOps "\.group_segment_align"
syntax match asmPseudoOps "\.half"
syntax match asmPseudoOps "\.header"
syntax match asmPseudoOps "\.hsa_debugmode"
syntax match asmPseudoOps "\.hsa_dims"
syntax match asmPseudoOps "\.hsa_dx10clamp"
syntax match asmPseudoOps "\.hsa_exceptions"
syntax match asmPseudoOps "\.hsa_floatmode"
syntax match asmPseudoOps "\.hsa_ieeemode"
syntax match asmPseudoOps "\.hsa_localsize"
syntax match asmPseudoOps "\.hsa_pgmrsrc1"
syntax match asmPseudoOps "\.hsa_pgmrsrc2"
syntax match asmPseudoOps "\.hsa_priority"
syntax match asmPseudoOps "\.hsa_privmode"
syntax match asmPseudoOps "\.hsa_scratchbuffer"
syntax match asmPseudoOps "\.hsa_sgprsnum"
syntax match asmPseudoOps "\.hsa_tgsize"
syntax match asmPseudoOps "\.hsa_userdatanum"
syntax match asmPseudoOps "\.hsa_vgprsnum"
syntax match asmPseudoOps "\.hsaconfig"
syntax match asmPseudoOps "\.hsalayout"
syntax match asmPseudoOps "\.hwlocal"
syntax match asmPseudoOps "\.hword"
syntax match asmPseudoOps "\.hwregion"
syntax match asmPseudoOps "\.ieeemode"
syntax match asmPseudoOps "\.inner"
syntax match asmPseudoOps "\.inputs"
syntax match asmPseudoOps "\.inputsamplers"
syntax match asmPseudoOps "\.int"
syntax match asmPseudoOps "\.intconsts"
syntax match asmPseudoOps "\.irp"
syntax match asmPseudoOps "\.irpc"
syntax match asmPseudoOps "\.isametadata"
syntax match asmPseudoOps "\.kcode"
syntax match asmPseudoOps "\.kcodeend"
syntax match asmPseudoOps "\.kernarg_segment_align"
syntax match asmPseudoOps "\.kernarg_segment_size"
syntax match asmPseudoOps "\.kernel"
syntax match asmPseudoOps "\.kernel_code_entry_offset"
syntax match asmPseudoOps "\.kernel_code_prefetch_offset"
syntax match asmPseudoOps "\.kernel_code_prefetch_size"
syntax match asmPseudoOps "\.lflags"
syntax match asmPseudoOps "\.line"
syntax match asmPseudoOps "\.llvm_version"
syntax match asmPseudoOps "\.ln"
syntax match asmPseudoOps "\.local"
syntax match asmPseudoOps "\.localsize"
syntax match asmPseudoOps "\.long"
syntax match asmPseudoOps "\.machine"
syntax match asmPseudoOps "\.macrocase"
syntax match asmPseudoOps "\.main"
syntax match asmPseudoOps "\.max_flat_work_group_size"
syntax match asmPseudoOps "\.max_scratch_backing_memory"
syntax match asmPseudoOps "\.md_group_segment_fixed_size"
syntax match asmPseudoOps "\.md_kernarg_segment_align"
syntax match asmPseudoOps "\.md_kernarg_segment_size"
syntax match asmPseudoOps "\.md_language"
syntax match asmPseudoOps "\.md_private_segment_fixed_size"
syntax match asmPseudoOps "\.md_sgprsnum"
syntax match asmPseudoOps "\.md_symname"
syntax match asmPseudoOps "\.md_version"
syntax match asmPseudoOps "\.md_vgprsnum"
syntax match asmPseudoOps "\.md_wavefront_size"
syntax match asmPseudoOps "\.metadata"
syntax match asmPseudoOps "\.newbinfmt"
syntax match asmPseudoOps "\.noaltmacro"
syntax match asmPseudoOps "\.nobuggyfplit"
syntax match asmPseudoOps "\.nomacrocase"
syntax match asmPseudoOps "\.nosectdiffs"
syntax match asmPseudoOps "\.octa"
syntax match asmPseudoOps "\.offset"
syntax match asmPseudoOps "\.org"
syntax match asmPseudoOps "\.outputs"
syntax match asmPseudoOps "\.p2align"
syntax match asmPseudoOps "\.persistentbuffers"
syntax match asmPseudoOps "\.pgmrsrc1"
syntax match asmPseudoOps "\.pgmrsrc2"
syntax match asmPseudoOps "\.policy"
syntax match asmPseudoOps "\.print"
syntax match asmPseudoOps "\.printfid"
syntax match asmPseudoOps "\.priority"
syntax match asmPseudoOps "\.private_elem_size"
syntax match asmPseudoOps "\.private_segment_align"
syntax match asmPseudoOps "\.privateid"
syntax match asmPseudoOps "\.privmode"
syntax match asmPseudoOps "\.proginfo"
syntax match asmPseudoOps "\.purgem"
syntax match asmPseudoOps "\.quad"
syntax match asmPseudoOps "\.rawcode"
syntax match asmPseudoOps "\.regvar"
syntax match asmPseudoOps "\.rept"
syntax match asmPseudoOps "\.reqd_work_group_size"
syntax match asmPseudoOps "\.reserved_sgprs"
syntax match asmPseudoOps "\.reserved_vgprs"
syntax match asmPseudoOps "\.rocm"
syntax match asmPseudoOps "\.rodata"
syntax match asmPseudoOps "\.runtime_handle"
syntax match asmPseudoOps "\.runtime_loader_kernel_symbol"
syntax match asmPseudoOps "\.rvlin"
syntax match asmPseudoOps "\.rvlin_once"
syntax match asmPseudoOps "\.rwdata"
syntax match asmPseudoOps "\.sampler"
syntax match asmPseudoOps "\.samplerinit"
syntax match asmPseudoOps "\.samplerreloc"
syntax match asmPseudoOps "\.sbttl"
syntax match asmPseudoOps "\.scope"
syntax match asmPseudoOps "\.scratchbuffer"
syntax match asmPseudoOps "\.scratchbuffers"
syntax match asmPseudoOps "\.scratchsym"
syntax match asmPseudoOps "\.section"
syntax match asmPseudoOps "\.segment"
syntax match asmPseudoOps "\.set"
syntax match asmPseudoOps "\.setup"
syntax match asmPseudoOps "\.setupargs"
syntax match asmPseudoOps "\.sgprsnum"
syntax match asmPseudoOps "\.short"
syntax match asmPseudoOps "\.single"
syntax match asmPseudoOps "\.size"
syntax match asmPseudoOps "\.skip"
syntax match asmPseudoOps "\.space"
syntax match asmPseudoOps "\.spilledsgprs"
syntax match asmPseudoOps "\.spilledvgprs"
syntax match asmPseudoOps "\.string"
syntax match asmPseudoOps "\.string16"
syntax match asmPseudoOps "\.string32"
syntax match asmPseudoOps "\.string64"
syntax match asmPseudoOps "\.struct"
syntax match asmPseudoOps "\.stub"
syntax match asmPseudoOps "\.subconstantbuffers"
syntax match asmPseudoOps "\.target"
syntax match asmPseudoOps "\.text"
syntax match asmPseudoOps "\.tgsize"
syntax match asmPseudoOps "\.title"
syntax match asmPseudoOps "\.tripple"
syntax match asmPseudoOps "\.uav"
syntax match asmPseudoOps "\.uavid"
syntax match asmPseudoOps "\.uavmailboxsize"
syntax match asmPseudoOps "\.uavopmask"
syntax match asmPseudoOps "\.uavprivate"
syntax match asmPseudoOps "\.undef"
syntax match asmPseudoOps "\.unusing"
syntax match asmPseudoOps "\.use_debug_enabled"
syntax match asmPseudoOps "\.use_dispatch_id"
syntax match asmPseudoOps "\.use_dispatch_ptr"
syntax match asmPseudoOps "\.use_dynamic_call_stack"
syntax match asmPseudoOps "\.use_flat_scratch_init"
syntax match asmPseudoOps "\.use_grid_workgroup_count"
syntax match asmPseudoOps "\.use_kernarg_segment_ptr"
syntax match asmPseudoOps "\.use_ordered_append_gds"
syntax match asmPseudoOps "\.use_private_segment_buffer"
syntax match asmPseudoOps "\.use_private_segment_size"
syntax match asmPseudoOps "\.use_ptr64"
syntax match asmPseudoOps "\.use_queue_ptr"
syntax match asmPseudoOps "\.use_xnack_enabled"
syntax match asmPseudoOps "\.useargs"
syntax match asmPseudoOps "\.useconstdata"
syntax match asmPseudoOps "\.useenqueue"
syntax match asmPseudoOps "\.usegeneric"
syntax match asmPseudoOps "\.useprintf"
syntax match asmPseudoOps "\.userdata"
syntax match asmPseudoOps "\.userdatanum"
syntax match asmPseudoOps "\.usereg"
syntax match asmPseudoOps "\.usesetup"
syntax match asmPseudoOps "\.using"
syntax match asmPseudoOps "\.vectypehint"
syntax match asmPseudoOps "\.version"
syntax match asmPseudoOps "\.vgprsnum"
syntax match asmPseudoOps "\.warning"
syntax match asmPseudoOps "\.wavefront_sgpr_count"
syntax match asmPseudoOps "\.wavefront_size"
syntax match asmPseudoOps "\.weak"
syntax match asmPseudoOps "\.while"
syntax match asmPseudoOps "\.word"
syntax match asmPseudoOps "\.work_group_size_hint"
syntax match asmPseudoOps "\.workgroup_fbarrier_count"
syntax match asmPseudoOps "\.workgroup_group_segment_size"
syntax match asmPseudoOps "\.workitem_private_segment_size"
syntax match asmPseudoOps "\.workitem_vgpr_count"

" conditional pseudo-ops
syntax match asmCondit "\.else"
syntax match asmCondit "\.elseif"
syntax match asmCondit "\.elseif32"
syntax match asmCondit "\.elseif64"
syntax match asmCondit "\.elseifarch"
syntax match asmCondit "\.elseifb"
syntax match asmCondit "\.elseifc"
syntax match asmCondit "\.elseifdef"
syntax match asmCondit "\.elseifeq"
syntax match asmCondit "\.elseifeqs"
syntax match asmCondit "\.elseiffmt"
syntax match asmCondit "\.elseifge"
syntax match asmCondit "\.elseifgpu"
syntax match asmCondit "\.elseifgt"
syntax match asmCondit "\.elseifle"
syntax match asmCondit "\.elseiflt"
syntax match asmCondit "\.elseifnarch"
syntax match asmCondit "\.elseifnb"
syntax match asmCondit "\.elseifnc"
syntax match asmCondit "\.elseifndef"
syntax match asmCondit "\.elseifne"
syntax match asmCondit "\.elseifnes"
syntax match asmCondit "\.elseifnfmt"
syntax match asmCondit "\.elseifngpu"
syntax match asmCondit "\.elseifnotdef"
syntax match asmCondit "\.endif"
syntax match asmCondit "\.if"
syntax match asmCondit "\.if32"
syntax match asmCondit "\.if64"
syntax match asmCondit "\.ifarch"
syntax match asmCondit "\.ifb"
syntax match asmCondit "\.ifc"
syntax match asmCondit "\.ifdef"
syntax match asmCondit "\.ifeq"
syntax match asmCondit "\.ifeqs"
syntax match asmCondit "\.iffmt"
syntax match asmCondit "\.ifge"
syntax match asmCondit "\.ifgpu"
syntax match asmCondit "\.ifgt"
syntax match asmCondit "\.ifle"
syntax match asmCondit "\.iflt"
syntax match asmCondit "\.ifnarch"
syntax match asmCondit "\.ifnb"
syntax match asmCondit "\.ifnc"
syntax match asmCondit "\.ifndef"
syntax match asmCondit "\.ifne"
syntax match asmCondit "\.ifnes"
syntax match asmCondit "\.ifnfmt"
syntax match asmCondit "\.ifngpu"
syntax match asmCondit "\.ifnotdef"

" macros
syntax match asmMacro "\.macro"
syntax match asmMacro "\.endm"
syntax match asmMacro "\.exitm"
syntax match asmMacro "\.endmacro"

" includes
syntax match asmInclude "\.include"
syntax match asmInclude "\.incbin"

"""
" GCN 1.0/1.1/1.2 register
"""

syntax match asmRegister "v\d+"
syntax match asmRegister "s\d+"
syntax match asmRegister "ttmp\d+"
syntax keyword asmRegister vcc vcc_lo vcc_hi exec exec_lo exec_hi
syntax keyword asmRegister flat_scratch flat_scratch_lo flat_scratch_hi
syntax keyword asmRegister xnack_mask xnack_mask_lo xnack_mask_hi
syntax keyword asmRegister tba tba_lo tba_hi tma tma_lo tma_hi m0
syntax keyword asmRegister scc src_scc execz src_execz vccz src_vccz
syntax keyword asmRegister shared_base src_shared_base shared_limit src_shared_limit
syntax keyword asmRegister private_base src_private_base private_limit src_private_limit
syntax keyword asmRegister pops_exiting_wave_id src_pops_exiting_wave_id

"""
" GCN 1.0/1.1/1.2 instructions
"""
syntax keyword asmInstr buffer_atomic_add
syntax keyword asmInstr buffer_atomic_add_x2
syntax keyword asmInstr buffer_atomic_and
syntax keyword asmInstr buffer_atomic_and_x2
syntax keyword asmInstr buffer_atomic_cmpswap
syntax keyword asmInstr buffer_atomic_cmpswap_x2
syntax keyword asmInstr buffer_atomic_dec
syntax keyword asmInstr buffer_atomic_dec_x2
syntax keyword asmInstr buffer_atomic_fcmpswap
syntax keyword asmInstr buffer_atomic_fcmpswap_x2
syntax keyword asmInstr buffer_atomic_fmax
syntax keyword asmInstr buffer_atomic_fmax_x2
syntax keyword asmInstr buffer_atomic_fmin
syntax keyword asmInstr buffer_atomic_fmin_x2
syntax keyword asmInstr buffer_atomic_inc
syntax keyword asmInstr buffer_atomic_inc_x2
syntax keyword asmInstr buffer_atomic_or
syntax keyword asmInstr buffer_atomic_or_x2
syntax keyword asmInstr buffer_atomic_rsub
syntax keyword asmInstr buffer_atomic_rsub_x2
syntax keyword asmInstr buffer_atomic_smax
syntax keyword asmInstr buffer_atomic_smax_x2
syntax keyword asmInstr buffer_atomic_smin
syntax keyword asmInstr buffer_atomic_smin_x2
syntax keyword asmInstr buffer_atomic_sub
syntax keyword asmInstr buffer_atomic_sub_x2
syntax keyword asmInstr buffer_atomic_swap
syntax keyword asmInstr buffer_atomic_swap_x2
syntax keyword asmInstr buffer_atomic_umax
syntax keyword asmInstr buffer_atomic_umax_x2
syntax keyword asmInstr buffer_atomic_umin
syntax keyword asmInstr buffer_atomic_umin_x2
syntax keyword asmInstr buffer_atomic_xor
syntax keyword asmInstr buffer_atomic_xor_x2
syntax keyword asmInstr buffer_load_dword
syntax keyword asmInstr buffer_load_dwordx2
syntax keyword asmInstr buffer_load_dwordx3
syntax keyword asmInstr buffer_load_dwordx4
syntax keyword asmInstr buffer_load_format_d16_hi_x
syntax keyword asmInstr buffer_load_format_d16_x
syntax keyword asmInstr buffer_load_format_d16_xy
syntax keyword asmInstr buffer_load_format_d16_xyz
syntax keyword asmInstr buffer_load_format_d16_xyzw
syntax keyword asmInstr buffer_load_format_x
syntax keyword asmInstr buffer_load_format_xy
syntax keyword asmInstr buffer_load_format_xyz
syntax keyword asmInstr buffer_load_format_xyzw
syntax keyword asmInstr buffer_load_sbyte
syntax keyword asmInstr buffer_load_sbyte_d16
syntax keyword asmInstr buffer_load_sbyte_d16_hi
syntax keyword asmInstr buffer_load_short_d16
syntax keyword asmInstr buffer_load_short_d16_hi
syntax keyword asmInstr buffer_load_sshort
syntax keyword asmInstr buffer_load_ubyte
syntax keyword asmInstr buffer_load_ubyte_d16
syntax keyword asmInstr buffer_load_ubyte_d16_hi
syntax keyword asmInstr buffer_load_ushort
syntax keyword asmInstr buffer_store_byte
syntax keyword asmInstr buffer_store_byte_d16_hi
syntax keyword asmInstr buffer_store_dword
syntax keyword asmInstr buffer_store_dwordx2
syntax keyword asmInstr buffer_store_dwordx3
syntax keyword asmInstr buffer_store_dwordx4
syntax keyword asmInstr buffer_store_format_d16_hi_x
syntax keyword asmInstr buffer_store_format_d16_x
syntax keyword asmInstr buffer_store_format_d16_xy
syntax keyword asmInstr buffer_store_format_d16_xyz
syntax keyword asmInstr buffer_store_format_d16_xyzw
syntax keyword asmInstr buffer_store_format_x
syntax keyword asmInstr buffer_store_format_xy
syntax keyword asmInstr buffer_store_format_xyz
syntax keyword asmInstr buffer_store_format_xyzw
syntax keyword asmInstr buffer_store_lds_dword
syntax keyword asmInstr buffer_store_short
syntax keyword asmInstr buffer_store_short_d16_hi
syntax keyword asmInstr buffer_wbinvl1
syntax keyword asmInstr buffer_wbinvl1_sc
syntax keyword asmInstr buffer_wbinvl1_vol
syntax keyword asmInstr ds_add_f32
syntax keyword asmInstr ds_add_rtn_f32
syntax keyword asmInstr ds_add_rtn_u32
syntax keyword asmInstr ds_add_rtn_u64
syntax keyword asmInstr ds_add_src2_f32
syntax keyword asmInstr ds_add_src2_u32
syntax keyword asmInstr ds_add_src2_u64
syntax keyword asmInstr ds_add_u32
syntax keyword asmInstr ds_add_u64
syntax keyword asmInstr ds_and_b32
syntax keyword asmInstr ds_and_b64
syntax keyword asmInstr ds_and_rtn_b32
syntax keyword asmInstr ds_and_rtn_b64
syntax keyword asmInstr ds_and_src2_b32
syntax keyword asmInstr ds_and_src2_b64
syntax keyword asmInstr ds_append
syntax keyword asmInstr ds_bpermute_b32
syntax keyword asmInstr ds_cmpst_b32
syntax keyword asmInstr ds_cmpst_b64
syntax keyword asmInstr ds_cmpst_f32
syntax keyword asmInstr ds_cmpst_f64
syntax keyword asmInstr ds_cmpst_rtn_b32
syntax keyword asmInstr ds_cmpst_rtn_b64
syntax keyword asmInstr ds_cmpst_rtn_f32
syntax keyword asmInstr ds_cmpst_rtn_f64
syntax keyword asmInstr ds_condxchg32_rtn_b128
syntax keyword asmInstr ds_condxchg32_rtn_b64
syntax keyword asmInstr ds_consume
syntax keyword asmInstr ds_dec_rtn_u32
syntax keyword asmInstr ds_dec_rtn_u64
syntax keyword asmInstr ds_dec_src2_u32
syntax keyword asmInstr ds_dec_src2_u64
syntax keyword asmInstr ds_dec_u32
syntax keyword asmInstr ds_dec_u64
syntax keyword asmInstr ds_gws_barrier
syntax keyword asmInstr ds_gws_init
syntax keyword asmInstr ds_gws_sema_br
syntax keyword asmInstr ds_gws_sema_p
syntax keyword asmInstr ds_gws_sema_release_all
syntax keyword asmInstr ds_gws_sema_v
syntax keyword asmInstr ds_inc_rtn_u32
syntax keyword asmInstr ds_inc_rtn_u64
syntax keyword asmInstr ds_inc_src2_u32
syntax keyword asmInstr ds_inc_src2_u64
syntax keyword asmInstr ds_inc_u32
syntax keyword asmInstr ds_inc_u64
syntax keyword asmInstr ds_max_f32
syntax keyword asmInstr ds_max_f64
syntax keyword asmInstr ds_max_i32
syntax keyword asmInstr ds_max_i64
syntax keyword asmInstr ds_max_rtn_f32
syntax keyword asmInstr ds_max_rtn_f64
syntax keyword asmInstr ds_max_rtn_i32
syntax keyword asmInstr ds_max_rtn_i64
syntax keyword asmInstr ds_max_rtn_u32
syntax keyword asmInstr ds_max_rtn_u64
syntax keyword asmInstr ds_max_src2_f32
syntax keyword asmInstr ds_max_src2_f64
syntax keyword asmInstr ds_max_src2_i32
syntax keyword asmInstr ds_max_src2_i64
syntax keyword asmInstr ds_max_src2_u32
syntax keyword asmInstr ds_max_src2_u64
syntax keyword asmInstr ds_max_u32
syntax keyword asmInstr ds_max_u64
syntax keyword asmInstr ds_min_f32
syntax keyword asmInstr ds_min_f64
syntax keyword asmInstr ds_min_i32
syntax keyword asmInstr ds_min_i64
syntax keyword asmInstr ds_min_rtn_f32
syntax keyword asmInstr ds_min_rtn_f64
syntax keyword asmInstr ds_min_rtn_i32
syntax keyword asmInstr ds_min_rtn_i64
syntax keyword asmInstr ds_min_rtn_u32
syntax keyword asmInstr ds_min_rtn_u64
syntax keyword asmInstr ds_min_src2_f32
syntax keyword asmInstr ds_min_src2_f64
syntax keyword asmInstr ds_min_src2_i32
syntax keyword asmInstr ds_min_src2_i64
syntax keyword asmInstr ds_min_src2_u32
syntax keyword asmInstr ds_min_src2_u64
syntax keyword asmInstr ds_min_u32
syntax keyword asmInstr ds_min_u64
syntax keyword asmInstr ds_mskor_b32
syntax keyword asmInstr ds_mskor_b64
syntax keyword asmInstr ds_mskor_rtn_b32
syntax keyword asmInstr ds_mskor_rtn_b64
syntax keyword asmInstr ds_nop
syntax keyword asmInstr ds_or_b32
syntax keyword asmInstr ds_or_b64
syntax keyword asmInstr ds_or_rtn_b32
syntax keyword asmInstr ds_or_rtn_b64
syntax keyword asmInstr ds_or_src2_b32
syntax keyword asmInstr ds_or_src2_b64
syntax keyword asmInstr ds_ordered_count
syntax keyword asmInstr ds_permute_b32
syntax keyword asmInstr ds_read2_b32
syntax keyword asmInstr ds_read2_b64
syntax keyword asmInstr ds_read2st64_b32
syntax keyword asmInstr ds_read2st64_b64
syntax keyword asmInstr ds_read_addtid_b32
syntax keyword asmInstr ds_read_b128
syntax keyword asmInstr ds_read_b32
syntax keyword asmInstr ds_read_b64
syntax keyword asmInstr ds_read_b96
syntax keyword asmInstr ds_read_i16
syntax keyword asmInstr ds_read_i8
syntax keyword asmInstr ds_read_i8_d16
syntax keyword asmInstr ds_read_i8_d16_hi
syntax keyword asmInstr ds_read_u16
syntax keyword asmInstr ds_read_u16_d16
syntax keyword asmInstr ds_read_u16_d16_hi
syntax keyword asmInstr ds_read_u8
syntax keyword asmInstr ds_read_u8_d16
syntax keyword asmInstr ds_read_u8_d16_hi
syntax keyword asmInstr ds_rsub_rtn_u32
syntax keyword asmInstr ds_rsub_rtn_u64
syntax keyword asmInstr ds_rsub_src2_u32
syntax keyword asmInstr ds_rsub_src2_u64
syntax keyword asmInstr ds_rsub_u32
syntax keyword asmInstr ds_rsub_u64
syntax keyword asmInstr ds_sub_rtn_u32
syntax keyword asmInstr ds_sub_rtn_u64
syntax keyword asmInstr ds_sub_src2_u32
syntax keyword asmInstr ds_sub_src2_u64
syntax keyword asmInstr ds_sub_u32
syntax keyword asmInstr ds_sub_u64
syntax keyword asmInstr ds_swizzle_b32
syntax keyword asmInstr ds_wrap_rtn_b32
syntax keyword asmInstr ds_write2_b32
syntax keyword asmInstr ds_write2_b64
syntax keyword asmInstr ds_write2st64_b32
syntax keyword asmInstr ds_write2st64_b64
syntax keyword asmInstr ds_write_addtid_b32
syntax keyword asmInstr ds_write_b128
syntax keyword asmInstr ds_write_b16
syntax keyword asmInstr ds_write_b16_d16_hi
syntax keyword asmInstr ds_write_b32
syntax keyword asmInstr ds_write_b64
syntax keyword asmInstr ds_write_b8
syntax keyword asmInstr ds_write_b8_d16_hi
syntax keyword asmInstr ds_write_b96
syntax keyword asmInstr ds_write_src2_b32
syntax keyword asmInstr ds_write_src2_b64
syntax keyword asmInstr ds_wrxchg2_rtn_b32
syntax keyword asmInstr ds_wrxchg2_rtn_b64
syntax keyword asmInstr ds_wrxchg2st64_rtn_b32
syntax keyword asmInstr ds_wrxchg2st64_rtn_b64
syntax keyword asmInstr ds_wrxchg_rtn_b32
syntax keyword asmInstr ds_wrxchg_rtn_b64
syntax keyword asmInstr ds_xor_b32
syntax keyword asmInstr ds_xor_b64
syntax keyword asmInstr ds_xor_rtn_b32
syntax keyword asmInstr ds_xor_rtn_b64
syntax keyword asmInstr ds_xor_src2_b32
syntax keyword asmInstr ds_xor_src2_b64
syntax keyword asmInstr exp
syntax keyword asmInstr flat_atomic_add
syntax keyword asmInstr flat_atomic_add_x2
syntax keyword asmInstr flat_atomic_and
syntax keyword asmInstr flat_atomic_and_x2
syntax keyword asmInstr flat_atomic_cmpswap
syntax keyword asmInstr flat_atomic_cmpswap_x2
syntax keyword asmInstr flat_atomic_dec
syntax keyword asmInstr flat_atomic_dec_x2
syntax keyword asmInstr flat_atomic_fcmpswap
syntax keyword asmInstr flat_atomic_fcmpswap_x2
syntax keyword asmInstr flat_atomic_fmax
syntax keyword asmInstr flat_atomic_fmax_x2
syntax keyword asmInstr flat_atomic_fmin
syntax keyword asmInstr flat_atomic_fmin_x2
syntax keyword asmInstr flat_atomic_inc
syntax keyword asmInstr flat_atomic_inc_x2
syntax keyword asmInstr flat_atomic_or
syntax keyword asmInstr flat_atomic_or_x2
syntax keyword asmInstr flat_atomic_smax
syntax keyword asmInstr flat_atomic_smax_x2
syntax keyword asmInstr flat_atomic_smin
syntax keyword asmInstr flat_atomic_smin_x2
syntax keyword asmInstr flat_atomic_sub
syntax keyword asmInstr flat_atomic_sub_x2
syntax keyword asmInstr flat_atomic_swap
syntax keyword asmInstr flat_atomic_swap_x2
syntax keyword asmInstr flat_atomic_umax
syntax keyword asmInstr flat_atomic_umax_x2
syntax keyword asmInstr flat_atomic_umin
syntax keyword asmInstr flat_atomic_umin_x2
syntax keyword asmInstr flat_atomic_xor
syntax keyword asmInstr flat_atomic_xor_x2
syntax keyword asmInstr flat_load_dword
syntax keyword asmInstr flat_load_dwordx2
syntax keyword asmInstr flat_load_dwordx3
syntax keyword asmInstr flat_load_dwordx4
syntax keyword asmInstr flat_load_sbyte
syntax keyword asmInstr flat_load_sbyte_d16
syntax keyword asmInstr flat_load_sbyte_d16_hi
syntax keyword asmInstr flat_load_short_d16
syntax keyword asmInstr flat_load_short_d16_hi
syntax keyword asmInstr flat_load_sshort
syntax keyword asmInstr flat_load_ubyte
syntax keyword asmInstr flat_load_ubyte_d16
syntax keyword asmInstr flat_load_ubyte_d16_hi
syntax keyword asmInstr flat_load_ushort
syntax keyword asmInstr flat_store_byte
syntax keyword asmInstr flat_store_byte_d16_hi
syntax keyword asmInstr flat_store_dword
syntax keyword asmInstr flat_store_dwordx2
syntax keyword asmInstr flat_store_dwordx3
syntax keyword asmInstr flat_store_dwordx4
syntax keyword asmInstr flat_store_short
syntax keyword asmInstr flat_store_short_d16_hi
syntax keyword asmInstr global_atomic_add
syntax keyword asmInstr global_atomic_add_x2
syntax keyword asmInstr global_atomic_and
syntax keyword asmInstr global_atomic_and_x2
syntax keyword asmInstr global_atomic_cmpswap
syntax keyword asmInstr global_atomic_cmpswap_x2
syntax keyword asmInstr global_atomic_dec
syntax keyword asmInstr global_atomic_dec_x2
syntax keyword asmInstr global_atomic_inc
syntax keyword asmInstr global_atomic_inc_x2
syntax keyword asmInstr global_atomic_or
syntax keyword asmInstr global_atomic_or_x2
syntax keyword asmInstr global_atomic_smax
syntax keyword asmInstr global_atomic_smax_x2
syntax keyword asmInstr global_atomic_smin
syntax keyword asmInstr global_atomic_smin_x2
syntax keyword asmInstr global_atomic_sub
syntax keyword asmInstr global_atomic_sub_x2
syntax keyword asmInstr global_atomic_swap
syntax keyword asmInstr global_atomic_swap_x2
syntax keyword asmInstr global_atomic_umax
syntax keyword asmInstr global_atomic_umax_x2
syntax keyword asmInstr global_atomic_umin
syntax keyword asmInstr global_atomic_umin_x2
syntax keyword asmInstr global_atomic_xor
syntax keyword asmInstr global_atomic_xor_x2
syntax keyword asmInstr global_load_dword
syntax keyword asmInstr global_load_dwordx2
syntax keyword asmInstr global_load_dwordx3
syntax keyword asmInstr global_load_dwordx4
syntax keyword asmInstr global_load_sbyte
syntax keyword asmInstr global_load_sbyte_d16
syntax keyword asmInstr global_load_sbyte_d16_hi
syntax keyword asmInstr global_load_short_d16
syntax keyword asmInstr global_load_short_d16_hi
syntax keyword asmInstr global_load_sshort
syntax keyword asmInstr global_load_ubyte
syntax keyword asmInstr global_load_ubyte_d16
syntax keyword asmInstr global_load_ubyte_d16_hi
syntax keyword asmInstr global_load_ushort
syntax keyword asmInstr global_store_byte
syntax keyword asmInstr global_store_byte_d16_hi
syntax keyword asmInstr global_store_dword
syntax keyword asmInstr global_store_dwordx2
syntax keyword asmInstr global_store_dwordx3
syntax keyword asmInstr global_store_dwordx4
syntax keyword asmInstr global_store_short
syntax keyword asmInstr global_store_short_d16_hi
syntax keyword asmInstr image_atomic_add
syntax keyword asmInstr image_atomic_and
syntax keyword asmInstr image_atomic_cmpswap
syntax keyword asmInstr image_atomic_dec
syntax keyword asmInstr image_atomic_fcmpswap
syntax keyword asmInstr image_atomic_fmax
syntax keyword asmInstr image_atomic_fmin
syntax keyword asmInstr image_atomic_inc
syntax keyword asmInstr image_atomic_or
syntax keyword asmInstr image_atomic_rsub
syntax keyword asmInstr image_atomic_smax
syntax keyword asmInstr image_atomic_smin
syntax keyword asmInstr image_atomic_sub
syntax keyword asmInstr image_atomic_swap
syntax keyword asmInstr image_atomic_umax
syntax keyword asmInstr image_atomic_umin
syntax keyword asmInstr image_atomic_xor
syntax keyword asmInstr image_gather4
syntax keyword asmInstr image_gather4_b
syntax keyword asmInstr image_gather4_b_cl
syntax keyword asmInstr image_gather4_b_cl_o
syntax keyword asmInstr image_gather4_b_o
syntax keyword asmInstr image_gather4_c
syntax keyword asmInstr image_gather4_c_b
syntax keyword asmInstr image_gather4_c_b_cl
syntax keyword asmInstr image_gather4_c_b_cl_o
syntax keyword asmInstr image_gather4_c_b_o
syntax keyword asmInstr image_gather4_c_cl
syntax keyword asmInstr image_gather4_c_cl_o
syntax keyword asmInstr image_gather4_c_l
syntax keyword asmInstr image_gather4_c_l_o
syntax keyword asmInstr image_gather4_c_lz
syntax keyword asmInstr image_gather4_c_lz_o
syntax keyword asmInstr image_gather4_c_o
syntax keyword asmInstr image_gather4_cl
syntax keyword asmInstr image_gather4_cl_o
syntax keyword asmInstr image_gather4_l
syntax keyword asmInstr image_gather4_l_o
syntax keyword asmInstr image_gather4_lz
syntax keyword asmInstr image_gather4_lz_o
syntax keyword asmInstr image_gather4_o
syntax keyword asmInstr image_gather4h
syntax keyword asmInstr image_gather4h_pck
syntax keyword asmInstr image_gather8h_pck
syntax keyword asmInstr image_get_lod
syntax keyword asmInstr image_get_resinfo
syntax keyword asmInstr image_load
syntax keyword asmInstr image_load_mip
syntax keyword asmInstr image_load_mip_pck
syntax keyword asmInstr image_load_mip_pck_sgn
syntax keyword asmInstr image_load_pck
syntax keyword asmInstr image_load_pck_sgn
syntax keyword asmInstr image_sample
syntax keyword asmInstr image_sample_b
syntax keyword asmInstr image_sample_b_cl
syntax keyword asmInstr image_sample_b_cl_o
syntax keyword asmInstr image_sample_b_o
syntax keyword asmInstr image_sample_c
syntax keyword asmInstr image_sample_c_b
syntax keyword asmInstr image_sample_c_b_cl
syntax keyword asmInstr image_sample_c_b_cl_o
syntax keyword asmInstr image_sample_c_b_o
syntax keyword asmInstr image_sample_c_cd
syntax keyword asmInstr image_sample_c_cd_cl
syntax keyword asmInstr image_sample_c_cd_cl_o
syntax keyword asmInstr image_sample_c_cd_o
syntax keyword asmInstr image_sample_c_cl
syntax keyword asmInstr image_sample_c_cl_o
syntax keyword asmInstr image_sample_c_d
syntax keyword asmInstr image_sample_c_d_cl
syntax keyword asmInstr image_sample_c_d_cl_o
syntax keyword asmInstr image_sample_c_d_o
syntax keyword asmInstr image_sample_c_l
syntax keyword asmInstr image_sample_c_l_o
syntax keyword asmInstr image_sample_c_lz
syntax keyword asmInstr image_sample_c_lz_o
syntax keyword asmInstr image_sample_c_o
syntax keyword asmInstr image_sample_cd
syntax keyword asmInstr image_sample_cd_cl
syntax keyword asmInstr image_sample_cd_cl_o
syntax keyword asmInstr image_sample_cd_o
syntax keyword asmInstr image_sample_cl
syntax keyword asmInstr image_sample_cl_o
syntax keyword asmInstr image_sample_d
syntax keyword asmInstr image_sample_d_cl
syntax keyword asmInstr image_sample_d_cl_o
syntax keyword asmInstr image_sample_d_o
syntax keyword asmInstr image_sample_l
syntax keyword asmInstr image_sample_l_o
syntax keyword asmInstr image_sample_lz
syntax keyword asmInstr image_sample_lz_o
syntax keyword asmInstr image_sample_o
syntax keyword asmInstr image_store
syntax keyword asmInstr image_store_mip
syntax keyword asmInstr image_store_mip_pck
syntax keyword asmInstr image_store_pck
syntax keyword asmInstr s_abs_i32
syntax keyword asmInstr s_absdiff_i32
syntax keyword asmInstr s_add_i32
syntax keyword asmInstr s_add_u32
syntax keyword asmInstr s_addc_u32
syntax keyword asmInstr s_addk_i32
syntax keyword asmInstr s_and_b32
syntax keyword asmInstr s_and_b64
syntax keyword asmInstr s_and_saveexec_b64
syntax keyword asmInstr s_andn1_saveexec_b64
syntax keyword asmInstr s_andn1_wrexec_b64
syntax keyword asmInstr s_andn2_b32
syntax keyword asmInstr s_andn2_b64
syntax keyword asmInstr s_andn2_saveexec_b64
syntax keyword asmInstr s_andn2_wrexec_b64
syntax keyword asmInstr s_ashr_i32
syntax keyword asmInstr s_ashr_i64
syntax keyword asmInstr s_atc_probe
syntax keyword asmInstr s_atc_probe_buffer
syntax keyword asmInstr s_atomic_add
syntax keyword asmInstr s_atomic_add_x2
syntax keyword asmInstr s_atomic_and
syntax keyword asmInstr s_atomic_and_x2
syntax keyword asmInstr s_atomic_cmpswap
syntax keyword asmInstr s_atomic_cmpswap_x2
syntax keyword asmInstr s_atomic_dec
syntax keyword asmInstr s_atomic_dec_x2
syntax keyword asmInstr s_atomic_inc
syntax keyword asmInstr s_atomic_inc_x2
syntax keyword asmInstr s_atomic_or
syntax keyword asmInstr s_atomic_or_x2
syntax keyword asmInstr s_atomic_smax
syntax keyword asmInstr s_atomic_smax_x2
syntax keyword asmInstr s_atomic_smin
syntax keyword asmInstr s_atomic_smin_x2
syntax keyword asmInstr s_atomic_sub
syntax keyword asmInstr s_atomic_sub_x2
syntax keyword asmInstr s_atomic_swap
syntax keyword asmInstr s_atomic_swap_x2
syntax keyword asmInstr s_atomic_umax
syntax keyword asmInstr s_atomic_umax_x2
syntax keyword asmInstr s_atomic_umin
syntax keyword asmInstr s_atomic_umin_x2
syntax keyword asmInstr s_atomic_xor
syntax keyword asmInstr s_atomic_xor_x2
syntax keyword asmInstr s_barrier
syntax keyword asmInstr s_bcnt0_i32_b32
syntax keyword asmInstr s_bcnt0_i32_b64
syntax keyword asmInstr s_bcnt1_i32_b32
syntax keyword asmInstr s_bcnt1_i32_b64
syntax keyword asmInstr s_bfe_i32
syntax keyword asmInstr s_bfe_i64
syntax keyword asmInstr s_bfe_u32
syntax keyword asmInstr s_bfe_u64
syntax keyword asmInstr s_bfm_b32
syntax keyword asmInstr s_bfm_b64
syntax keyword asmInstr s_bitcmp0_b32
syntax keyword asmInstr s_bitcmp0_b64
syntax keyword asmInstr s_bitcmp1_b32
syntax keyword asmInstr s_bitcmp1_b64
syntax keyword asmInstr s_bitreplicate_b64_b32
syntax keyword asmInstr s_bitset0_b32
syntax keyword asmInstr s_bitset0_b64
syntax keyword asmInstr s_bitset1_b32
syntax keyword asmInstr s_bitset1_b64
syntax keyword asmInstr s_branch
syntax keyword asmInstr s_brev_b32
syntax keyword asmInstr s_brev_b64
syntax keyword asmInstr s_buffer_atomic_add
syntax keyword asmInstr s_buffer_atomic_add_x2
syntax keyword asmInstr s_buffer_atomic_and
syntax keyword asmInstr s_buffer_atomic_and_x2
syntax keyword asmInstr s_buffer_atomic_cmpswap
syntax keyword asmInstr s_buffer_atomic_cmpswap_x2
syntax keyword asmInstr s_buffer_atomic_dec
syntax keyword asmInstr s_buffer_atomic_dec_x2
syntax keyword asmInstr s_buffer_atomic_inc
syntax keyword asmInstr s_buffer_atomic_inc_x2
syntax keyword asmInstr s_buffer_atomic_or
syntax keyword asmInstr s_buffer_atomic_or_x2
syntax keyword asmInstr s_buffer_atomic_smax
syntax keyword asmInstr s_buffer_atomic_smax_x2
syntax keyword asmInstr s_buffer_atomic_smin
syntax keyword asmInstr s_buffer_atomic_smin_x2
syntax keyword asmInstr s_buffer_atomic_sub
syntax keyword asmInstr s_buffer_atomic_sub_x2
syntax keyword asmInstr s_buffer_atomic_swap
syntax keyword asmInstr s_buffer_atomic_swap_x2
syntax keyword asmInstr s_buffer_atomic_umax
syntax keyword asmInstr s_buffer_atomic_umax_x2
syntax keyword asmInstr s_buffer_atomic_umin
syntax keyword asmInstr s_buffer_atomic_umin_x2
syntax keyword asmInstr s_buffer_atomic_xor
syntax keyword asmInstr s_buffer_atomic_xor_x2
syntax keyword asmInstr s_buffer_load_dword
syntax keyword asmInstr s_buffer_load_dwordx16
syntax keyword asmInstr s_buffer_load_dwordx2
syntax keyword asmInstr s_buffer_load_dwordx4
syntax keyword asmInstr s_buffer_load_dwordx8
syntax keyword asmInstr s_buffer_store_dword
syntax keyword asmInstr s_buffer_store_dwordx2
syntax keyword asmInstr s_buffer_store_dwordx4
syntax keyword asmInstr s_call_b64
syntax keyword asmInstr s_cbranch_cdbgsys
syntax keyword asmInstr s_cbranch_cdbgsys_and_user
syntax keyword asmInstr s_cbranch_cdbgsys_or_user
syntax keyword asmInstr s_cbranch_cdbguser
syntax keyword asmInstr s_cbranch_execnz
syntax keyword asmInstr s_cbranch_execz
syntax keyword asmInstr s_cbranch_g_fork
syntax keyword asmInstr s_cbranch_i_fork
syntax keyword asmInstr s_cbranch_join
syntax keyword asmInstr s_cbranch_scc0
syntax keyword asmInstr s_cbranch_scc1
syntax keyword asmInstr s_cbranch_vccnz
syntax keyword asmInstr s_cbranch_vccz
syntax keyword asmInstr s_cmov_b32
syntax keyword asmInstr s_cmov_b64
syntax keyword asmInstr s_cmovk_i32
syntax keyword asmInstr s_cmp_eq_i32
syntax keyword asmInstr s_cmp_eq_u32
syntax keyword asmInstr s_cmp_eq_u64
syntax keyword asmInstr s_cmp_ge_i32
syntax keyword asmInstr s_cmp_ge_u32
syntax keyword asmInstr s_cmp_gt_i32
syntax keyword asmInstr s_cmp_gt_u32
syntax keyword asmInstr s_cmp_le_i32
syntax keyword asmInstr s_cmp_le_u32
syntax keyword asmInstr s_cmp_lg_i32
syntax keyword asmInstr s_cmp_lg_u32
syntax keyword asmInstr s_cmp_lg_u64
syntax keyword asmInstr s_cmp_lt_i32
syntax keyword asmInstr s_cmp_lt_u32
syntax keyword asmInstr s_cmp_ne_u64
syntax keyword asmInstr s_cmpk_eq_i32
syntax keyword asmInstr s_cmpk_eq_u32
syntax keyword asmInstr s_cmpk_ge_i32
syntax keyword asmInstr s_cmpk_ge_u32
syntax keyword asmInstr s_cmpk_gt_i32
syntax keyword asmInstr s_cmpk_gt_u32
syntax keyword asmInstr s_cmpk_le_i32
syntax keyword asmInstr s_cmpk_le_u32
syntax keyword asmInstr s_cmpk_lg_i32
syntax keyword asmInstr s_cmpk_lg_u32
syntax keyword asmInstr s_cmpk_lt_i32
syntax keyword asmInstr s_cmpk_lt_u32
syntax keyword asmInstr s_cselect_b32
syntax keyword asmInstr s_cselect_b64
syntax keyword asmInstr s_dcache_discard
syntax keyword asmInstr s_dcache_discard_x2
syntax keyword asmInstr s_dcache_inv
syntax keyword asmInstr s_dcache_inv_vol
syntax keyword asmInstr s_dcache_wb
syntax keyword asmInstr s_dcache_wb_vol
syntax keyword asmInstr s_decperflevel
syntax keyword asmInstr s_endpgm
syntax keyword asmInstr s_endpgm_ordered_ps_done
syntax keyword asmInstr s_endpgm_saved
syntax keyword asmInstr s_ff0_i32_b32
syntax keyword asmInstr s_ff0_i32_b64
syntax keyword asmInstr s_ff1_i32_b32
syntax keyword asmInstr s_ff1_i32_b64
syntax keyword asmInstr s_flbit_i32
syntax keyword asmInstr s_flbit_i32_b32
syntax keyword asmInstr s_flbit_i32_b64
syntax keyword asmInstr s_flbit_i32_i64
syntax keyword asmInstr s_getpc_b64
syntax keyword asmInstr s_getreg_b32
syntax keyword asmInstr s_getreg_regrd_b32
syntax keyword asmInstr s_icache_inv
syntax keyword asmInstr s_incperflevel
syntax keyword asmInstr s_load_dword
syntax keyword asmInstr s_load_dwordx16
syntax keyword asmInstr s_load_dwordx2
syntax keyword asmInstr s_load_dwordx4
syntax keyword asmInstr s_load_dwordx8
syntax keyword asmInstr s_lshl1_add_u32
syntax keyword asmInstr s_lshl2_add_u32
syntax keyword asmInstr s_lshl3_add_u32
syntax keyword asmInstr s_lshl4_add_u32
syntax keyword asmInstr s_lshl_b32
syntax keyword asmInstr s_lshl_b64
syntax keyword asmInstr s_lshr_b32
syntax keyword asmInstr s_lshr_b64
syntax keyword asmInstr s_max_i32
syntax keyword asmInstr s_max_u32
syntax keyword asmInstr s_memrealtime
syntax keyword asmInstr s_memtime
syntax keyword asmInstr s_min_i32
syntax keyword asmInstr s_min_u32
syntax keyword asmInstr s_mov_b32
syntax keyword asmInstr s_mov_b64
syntax keyword asmInstr s_mov_fed_b32
syntax keyword asmInstr s_mov_regrd_b32
syntax keyword asmInstr s_movk_i32
syntax keyword asmInstr s_movreld_b32
syntax keyword asmInstr s_movreld_b64
syntax keyword asmInstr s_movrels_b32
syntax keyword asmInstr s_movrels_b64
syntax keyword asmInstr s_mul_hi_i32
syntax keyword asmInstr s_mul_hi_u32
syntax keyword asmInstr s_mul_i32
syntax keyword asmInstr s_mulk_i32
syntax keyword asmInstr s_nand_b32
syntax keyword asmInstr s_nand_b64
syntax keyword asmInstr s_nand_saveexec_b64
syntax keyword asmInstr s_nop
syntax keyword asmInstr s_nor_b32
syntax keyword asmInstr s_nor_b64
syntax keyword asmInstr s_nor_saveexec_b64
syntax keyword asmInstr s_not_b32
syntax keyword asmInstr s_not_b64
syntax keyword asmInstr s_or_b32
syntax keyword asmInstr s_or_b64
syntax keyword asmInstr s_or_saveexec_b64
syntax keyword asmInstr s_orn1_saveexec_b64
syntax keyword asmInstr s_orn2_b32
syntax keyword asmInstr s_orn2_b64
syntax keyword asmInstr s_orn2_saveexec_b64
syntax keyword asmInstr s_pack_hh_b32_b16
syntax keyword asmInstr s_pack_lh_b32_b16
syntax keyword asmInstr s_pack_ll_b32_b16
syntax keyword asmInstr s_quadmask_b32
syntax keyword asmInstr s_quadmask_b64
syntax keyword asmInstr s_rfe_b64
syntax keyword asmInstr s_rfe_restore_b64
syntax keyword asmInstr s_scratch_load_dword
syntax keyword asmInstr s_scratch_load_dwordx2
syntax keyword asmInstr s_scratch_load_dwordx4
syntax keyword asmInstr s_scratch_store_dword
syntax keyword asmInstr s_scratch_store_dwordx2
syntax keyword asmInstr s_scratch_store_dwordx4
syntax keyword asmInstr s_sendmsg
syntax keyword asmInstr s_sendmsghalt
syntax keyword asmInstr s_set_gpr_idx_idx
syntax keyword asmInstr s_set_gpr_idx_mode
syntax keyword asmInstr s_set_gpr_idx_off
syntax keyword asmInstr s_set_gpr_idx_on
syntax keyword asmInstr s_sethalt
syntax keyword asmInstr s_setkill
syntax keyword asmInstr s_setpc_b64
syntax keyword asmInstr s_setprio
syntax keyword asmInstr s_setreg_b32
syntax keyword asmInstr s_setreg_imm32_b32
syntax keyword asmInstr s_setvskip
syntax keyword asmInstr s_sext_i32_i16
syntax keyword asmInstr s_sext_i32_i8
syntax keyword asmInstr s_sleep
syntax keyword asmInstr s_store_dword
syntax keyword asmInstr s_store_dwordx2
syntax keyword asmInstr s_store_dwordx4
syntax keyword asmInstr s_sub_i32
syntax keyword asmInstr s_sub_u32
syntax keyword asmInstr s_subb_u32
syntax keyword asmInstr s_swappc_b64
syntax keyword asmInstr s_trap
syntax keyword asmInstr s_ttracedata
syntax keyword asmInstr s_waitcnt
syntax keyword asmInstr s_wakeup
syntax keyword asmInstr s_wqm_b32
syntax keyword asmInstr s_wqm_b64
syntax keyword asmInstr s_xnor_b32
syntax keyword asmInstr s_xnor_b64
syntax keyword asmInstr s_xnor_saveexec_b64
syntax keyword asmInstr s_xor_b32
syntax keyword asmInstr s_xor_b64
syntax keyword asmInstr s_xor_saveexec_b64
syntax keyword asmInstr scratch_load_dword
syntax keyword asmInstr scratch_load_dwordx2
syntax keyword asmInstr scratch_load_dwordx3
syntax keyword asmInstr scratch_load_dwordx4
syntax keyword asmInstr scratch_load_sbyte
syntax keyword asmInstr scratch_load_sbyte_d16
syntax keyword asmInstr scratch_load_sbyte_d16_hi
syntax keyword asmInstr scratch_load_short_d16
syntax keyword asmInstr scratch_load_short_d16_hi
syntax keyword asmInstr scratch_load_sshort
syntax keyword asmInstr scratch_load_ubyte
syntax keyword asmInstr scratch_load_ubyte_d16
syntax keyword asmInstr scratch_load_ubyte_d16_hi
syntax keyword asmInstr scratch_load_ushort
syntax keyword asmInstr scratch_store_byte
syntax keyword asmInstr scratch_store_byte_d16_hi
syntax keyword asmInstr scratch_store_dword
syntax keyword asmInstr scratch_store_dwordx2
syntax keyword asmInstr scratch_store_dwordx3
syntax keyword asmInstr scratch_store_dwordx4
syntax keyword asmInstr scratch_store_short
syntax keyword asmInstr scratch_store_short_d16_hi
syntax keyword asmInstr tbuffer_load_format_d16_x
syntax keyword asmInstr tbuffer_load_format_d16_xy
syntax keyword asmInstr tbuffer_load_format_d16_xyz
syntax keyword asmInstr tbuffer_load_format_d16_xyzw
syntax keyword asmInstr tbuffer_load_format_x
syntax keyword asmInstr tbuffer_load_format_xy
syntax keyword asmInstr tbuffer_load_format_xyz
syntax keyword asmInstr tbuffer_load_format_xyzw
syntax keyword asmInstr tbuffer_store_format_d16_x
syntax keyword asmInstr tbuffer_store_format_d16_xy
syntax keyword asmInstr tbuffer_store_format_d16_xyz
syntax keyword asmInstr tbuffer_store_format_d16_xyzw
syntax keyword asmInstr tbuffer_store_format_x
syntax keyword asmInstr tbuffer_store_format_xy
syntax keyword asmInstr tbuffer_store_format_xyz
syntax keyword asmInstr tbuffer_store_format_xyzw
syntax keyword asmInstr v_add3_u32
syntax keyword asmInstr v_add_co_u32
syntax keyword asmInstr v_add_f16
syntax keyword asmInstr v_add_f32
syntax keyword asmInstr v_add_f64
syntax keyword asmInstr v_add_i16
syntax keyword asmInstr v_add_i32
syntax keyword asmInstr v_add_lshl_u32
syntax keyword asmInstr v_add_u16
syntax keyword asmInstr v_add_u32
syntax keyword asmInstr v_addc_co_u32
syntax keyword asmInstr v_addc_u32
syntax keyword asmInstr v_alignbit_b32
syntax keyword asmInstr v_alignbyte_b32
syntax keyword asmInstr v_and_b32
syntax keyword asmInstr v_and_or_b32
syntax keyword asmInstr v_ashr_i32
syntax keyword asmInstr v_ashr_i64
syntax keyword asmInstr v_ashrrev_i16
syntax keyword asmInstr v_ashrrev_i32
syntax keyword asmInstr v_ashrrev_i64
syntax keyword asmInstr v_bcnt_u32_b32
syntax keyword asmInstr v_bfe_i32
syntax keyword asmInstr v_bfe_u32
syntax keyword asmInstr v_bfi_b32
syntax keyword asmInstr v_bfm_b32
syntax keyword asmInstr v_bfrev_b32
syntax keyword asmInstr v_ceil_f16
syntax keyword asmInstr v_ceil_f32
syntax keyword asmInstr v_ceil_f64
syntax keyword asmInstr v_clrexcp
syntax keyword asmInstr v_cmp_class_f16
syntax keyword asmInstr v_cmp_class_f32
syntax keyword asmInstr v_cmp_class_f64
syntax keyword asmInstr v_cmp_eq_f16
syntax keyword asmInstr v_cmp_eq_f32
syntax keyword asmInstr v_cmp_eq_f64
syntax keyword asmInstr v_cmp_eq_i16
syntax keyword asmInstr v_cmp_eq_i32
syntax keyword asmInstr v_cmp_eq_i64
syntax keyword asmInstr v_cmp_eq_u16
syntax keyword asmInstr v_cmp_eq_u32
syntax keyword asmInstr v_cmp_eq_u64
syntax keyword asmInstr v_cmp_f_f16
syntax keyword asmInstr v_cmp_f_f32
syntax keyword asmInstr v_cmp_f_f64
syntax keyword asmInstr v_cmp_f_i16
syntax keyword asmInstr v_cmp_f_i32
syntax keyword asmInstr v_cmp_f_i64
syntax keyword asmInstr v_cmp_f_u16
syntax keyword asmInstr v_cmp_f_u32
syntax keyword asmInstr v_cmp_f_u64
syntax keyword asmInstr v_cmp_ge_f16
syntax keyword asmInstr v_cmp_ge_f32
syntax keyword asmInstr v_cmp_ge_f64
syntax keyword asmInstr v_cmp_ge_i16
syntax keyword asmInstr v_cmp_ge_i32
syntax keyword asmInstr v_cmp_ge_i64
syntax keyword asmInstr v_cmp_ge_u16
syntax keyword asmInstr v_cmp_ge_u32
syntax keyword asmInstr v_cmp_ge_u64
syntax keyword asmInstr v_cmp_gt_f16
syntax keyword asmInstr v_cmp_gt_f32
syntax keyword asmInstr v_cmp_gt_f64
syntax keyword asmInstr v_cmp_gt_i16
syntax keyword asmInstr v_cmp_gt_i32
syntax keyword asmInstr v_cmp_gt_i64
syntax keyword asmInstr v_cmp_gt_u16
syntax keyword asmInstr v_cmp_gt_u32
syntax keyword asmInstr v_cmp_gt_u64
syntax keyword asmInstr v_cmp_le_f16
syntax keyword asmInstr v_cmp_le_f32
syntax keyword asmInstr v_cmp_le_f64
syntax keyword asmInstr v_cmp_le_i16
syntax keyword asmInstr v_cmp_le_i32
syntax keyword asmInstr v_cmp_le_i64
syntax keyword asmInstr v_cmp_le_u16
syntax keyword asmInstr v_cmp_le_u32
syntax keyword asmInstr v_cmp_le_u64
syntax keyword asmInstr v_cmp_lg_f16
syntax keyword asmInstr v_cmp_lg_f32
syntax keyword asmInstr v_cmp_lg_f64
syntax keyword asmInstr v_cmp_lg_i16
syntax keyword asmInstr v_cmp_lg_i32
syntax keyword asmInstr v_cmp_lg_i64
syntax keyword asmInstr v_cmp_lg_u16
syntax keyword asmInstr v_cmp_lg_u32
syntax keyword asmInstr v_cmp_lg_u64
syntax keyword asmInstr v_cmp_lt_f16
syntax keyword asmInstr v_cmp_lt_f32
syntax keyword asmInstr v_cmp_lt_f64
syntax keyword asmInstr v_cmp_lt_i16
syntax keyword asmInstr v_cmp_lt_i32
syntax keyword asmInstr v_cmp_lt_i64
syntax keyword asmInstr v_cmp_lt_u16
syntax keyword asmInstr v_cmp_lt_u32
syntax keyword asmInstr v_cmp_lt_u64
syntax keyword asmInstr v_cmp_ne_i16
syntax keyword asmInstr v_cmp_ne_i32
syntax keyword asmInstr v_cmp_ne_i64
syntax keyword asmInstr v_cmp_ne_u16
syntax keyword asmInstr v_cmp_ne_u32
syntax keyword asmInstr v_cmp_ne_u64
syntax keyword asmInstr v_cmp_neq_f16
syntax keyword asmInstr v_cmp_neq_f32
syntax keyword asmInstr v_cmp_neq_f64
syntax keyword asmInstr v_cmp_nge_f16
syntax keyword asmInstr v_cmp_nge_f32
syntax keyword asmInstr v_cmp_nge_f64
syntax keyword asmInstr v_cmp_ngt_f16
syntax keyword asmInstr v_cmp_ngt_f32
syntax keyword asmInstr v_cmp_ngt_f64
syntax keyword asmInstr v_cmp_nle_f16
syntax keyword asmInstr v_cmp_nle_f32
syntax keyword asmInstr v_cmp_nle_f64
syntax keyword asmInstr v_cmp_nlg_f16
syntax keyword asmInstr v_cmp_nlg_f32
syntax keyword asmInstr v_cmp_nlg_f64
syntax keyword asmInstr v_cmp_nlt_f16
syntax keyword asmInstr v_cmp_nlt_f32
syntax keyword asmInstr v_cmp_nlt_f64
syntax keyword asmInstr v_cmp_o_f16
syntax keyword asmInstr v_cmp_o_f32
syntax keyword asmInstr v_cmp_o_f64
syntax keyword asmInstr v_cmp_t_f16
syntax keyword asmInstr v_cmp_t_f32
syntax keyword asmInstr v_cmp_t_f64
syntax keyword asmInstr v_cmp_t_i16
syntax keyword asmInstr v_cmp_t_i32
syntax keyword asmInstr v_cmp_t_i64
syntax keyword asmInstr v_cmp_t_u16
syntax keyword asmInstr v_cmp_t_u32
syntax keyword asmInstr v_cmp_t_u64
syntax keyword asmInstr v_cmp_tru_f16
syntax keyword asmInstr v_cmp_tru_f32
syntax keyword asmInstr v_cmp_tru_f64
syntax keyword asmInstr v_cmp_tru_i16
syntax keyword asmInstr v_cmp_tru_i32
syntax keyword asmInstr v_cmp_tru_i64
syntax keyword asmInstr v_cmp_tru_u16
syntax keyword asmInstr v_cmp_tru_u32
syntax keyword asmInstr v_cmp_tru_u64
syntax keyword asmInstr v_cmp_u_f16
syntax keyword asmInstr v_cmp_u_f32
syntax keyword asmInstr v_cmp_u_f64
syntax keyword asmInstr v_cmps_eq_f32
syntax keyword asmInstr v_cmps_eq_f64
syntax keyword asmInstr v_cmps_f_f32
syntax keyword asmInstr v_cmps_f_f64
syntax keyword asmInstr v_cmps_ge_f32
syntax keyword asmInstr v_cmps_ge_f64
syntax keyword asmInstr v_cmps_gt_f32
syntax keyword asmInstr v_cmps_gt_f64
syntax keyword asmInstr v_cmps_le_f32
syntax keyword asmInstr v_cmps_le_f64
syntax keyword asmInstr v_cmps_lg_f32
syntax keyword asmInstr v_cmps_lg_f64
syntax keyword asmInstr v_cmps_lt_f32
syntax keyword asmInstr v_cmps_lt_f64
syntax keyword asmInstr v_cmps_neq_f32
syntax keyword asmInstr v_cmps_neq_f64
syntax keyword asmInstr v_cmps_nge_f32
syntax keyword asmInstr v_cmps_nge_f64
syntax keyword asmInstr v_cmps_ngt_f32
syntax keyword asmInstr v_cmps_ngt_f64
syntax keyword asmInstr v_cmps_nle_f32
syntax keyword asmInstr v_cmps_nle_f64
syntax keyword asmInstr v_cmps_nlg_f32
syntax keyword asmInstr v_cmps_nlg_f64
syntax keyword asmInstr v_cmps_nlt_f32
syntax keyword asmInstr v_cmps_nlt_f64
syntax keyword asmInstr v_cmps_o_f32
syntax keyword asmInstr v_cmps_o_f64
syntax keyword asmInstr v_cmps_t_f32
syntax keyword asmInstr v_cmps_t_f64
syntax keyword asmInstr v_cmps_tru_f32
syntax keyword asmInstr v_cmps_tru_f64
syntax keyword asmInstr v_cmps_u_f32
syntax keyword asmInstr v_cmps_u_f64
syntax keyword asmInstr v_cmpsx_eq_f32
syntax keyword asmInstr v_cmpsx_eq_f64
syntax keyword asmInstr v_cmpsx_f_f32
syntax keyword asmInstr v_cmpsx_f_f64
syntax keyword asmInstr v_cmpsx_ge_f32
syntax keyword asmInstr v_cmpsx_ge_f64
syntax keyword asmInstr v_cmpsx_gt_f32
syntax keyword asmInstr v_cmpsx_gt_f64
syntax keyword asmInstr v_cmpsx_le_f32
syntax keyword asmInstr v_cmpsx_le_f64
syntax keyword asmInstr v_cmpsx_lg_f32
syntax keyword asmInstr v_cmpsx_lg_f64
syntax keyword asmInstr v_cmpsx_lt_f32
syntax keyword asmInstr v_cmpsx_lt_f64
syntax keyword asmInstr v_cmpsx_neq_f32
syntax keyword asmInstr v_cmpsx_neq_f64
syntax keyword asmInstr v_cmpsx_nge_f32
syntax keyword asmInstr v_cmpsx_nge_f64
syntax keyword asmInstr v_cmpsx_ngt_f32
syntax keyword asmInstr v_cmpsx_ngt_f64
syntax keyword asmInstr v_cmpsx_nle_f32
syntax keyword asmInstr v_cmpsx_nle_f64
syntax keyword asmInstr v_cmpsx_nlg_f32
syntax keyword asmInstr v_cmpsx_nlg_f64
syntax keyword asmInstr v_cmpsx_nlt_f32
syntax keyword asmInstr v_cmpsx_nlt_f64
syntax keyword asmInstr v_cmpsx_o_f32
syntax keyword asmInstr v_cmpsx_o_f64
syntax keyword asmInstr v_cmpsx_t_f32
syntax keyword asmInstr v_cmpsx_t_f64
syntax keyword asmInstr v_cmpsx_tru_f32
syntax keyword asmInstr v_cmpsx_tru_f64
syntax keyword asmInstr v_cmpsx_u_f32
syntax keyword asmInstr v_cmpsx_u_f64
syntax keyword asmInstr v_cmpx_class_f16
syntax keyword asmInstr v_cmpx_class_f32
syntax keyword asmInstr v_cmpx_class_f64
syntax keyword asmInstr v_cmpx_eq_f16
syntax keyword asmInstr v_cmpx_eq_f32
syntax keyword asmInstr v_cmpx_eq_f64
syntax keyword asmInstr v_cmpx_eq_i16
syntax keyword asmInstr v_cmpx_eq_i32
syntax keyword asmInstr v_cmpx_eq_i64
syntax keyword asmInstr v_cmpx_eq_u16
syntax keyword asmInstr v_cmpx_eq_u32
syntax keyword asmInstr v_cmpx_eq_u64
syntax keyword asmInstr v_cmpx_f_f16
syntax keyword asmInstr v_cmpx_f_f32
syntax keyword asmInstr v_cmpx_f_f64
syntax keyword asmInstr v_cmpx_f_i16
syntax keyword asmInstr v_cmpx_f_i32
syntax keyword asmInstr v_cmpx_f_i64
syntax keyword asmInstr v_cmpx_f_u16
syntax keyword asmInstr v_cmpx_f_u32
syntax keyword asmInstr v_cmpx_f_u64
syntax keyword asmInstr v_cmpx_ge_f16
syntax keyword asmInstr v_cmpx_ge_f32
syntax keyword asmInstr v_cmpx_ge_f64
syntax keyword asmInstr v_cmpx_ge_i16
syntax keyword asmInstr v_cmpx_ge_i32
syntax keyword asmInstr v_cmpx_ge_i64
syntax keyword asmInstr v_cmpx_ge_u16
syntax keyword asmInstr v_cmpx_ge_u32
syntax keyword asmInstr v_cmpx_ge_u64
syntax keyword asmInstr v_cmpx_gt_f16
syntax keyword asmInstr v_cmpx_gt_f32
syntax keyword asmInstr v_cmpx_gt_f64
syntax keyword asmInstr v_cmpx_gt_i16
syntax keyword asmInstr v_cmpx_gt_i32
syntax keyword asmInstr v_cmpx_gt_i64
syntax keyword asmInstr v_cmpx_gt_u16
syntax keyword asmInstr v_cmpx_gt_u32
syntax keyword asmInstr v_cmpx_gt_u64
syntax keyword asmInstr v_cmpx_le_f16
syntax keyword asmInstr v_cmpx_le_f32
syntax keyword asmInstr v_cmpx_le_f64
syntax keyword asmInstr v_cmpx_le_i16
syntax keyword asmInstr v_cmpx_le_i32
syntax keyword asmInstr v_cmpx_le_i64
syntax keyword asmInstr v_cmpx_le_u16
syntax keyword asmInstr v_cmpx_le_u32
syntax keyword asmInstr v_cmpx_le_u64
syntax keyword asmInstr v_cmpx_lg_f16
syntax keyword asmInstr v_cmpx_lg_f32
syntax keyword asmInstr v_cmpx_lg_f64
syntax keyword asmInstr v_cmpx_lg_i16
syntax keyword asmInstr v_cmpx_lg_i32
syntax keyword asmInstr v_cmpx_lg_i64
syntax keyword asmInstr v_cmpx_lg_u16
syntax keyword asmInstr v_cmpx_lg_u32
syntax keyword asmInstr v_cmpx_lg_u64
syntax keyword asmInstr v_cmpx_lt_f16
syntax keyword asmInstr v_cmpx_lt_f32
syntax keyword asmInstr v_cmpx_lt_f64
syntax keyword asmInstr v_cmpx_lt_i16
syntax keyword asmInstr v_cmpx_lt_i32
syntax keyword asmInstr v_cmpx_lt_i64
syntax keyword asmInstr v_cmpx_lt_u16
syntax keyword asmInstr v_cmpx_lt_u32
syntax keyword asmInstr v_cmpx_lt_u64
syntax keyword asmInstr v_cmpx_ne_i16
syntax keyword asmInstr v_cmpx_ne_i32
syntax keyword asmInstr v_cmpx_ne_i64
syntax keyword asmInstr v_cmpx_ne_u16
syntax keyword asmInstr v_cmpx_ne_u32
syntax keyword asmInstr v_cmpx_ne_u64
syntax keyword asmInstr v_cmpx_neq_f16
syntax keyword asmInstr v_cmpx_neq_f32
syntax keyword asmInstr v_cmpx_neq_f64
syntax keyword asmInstr v_cmpx_nge_f16
syntax keyword asmInstr v_cmpx_nge_f32
syntax keyword asmInstr v_cmpx_nge_f64
syntax keyword asmInstr v_cmpx_ngt_f16
syntax keyword asmInstr v_cmpx_ngt_f32
syntax keyword asmInstr v_cmpx_ngt_f64
syntax keyword asmInstr v_cmpx_nle_f16
syntax keyword asmInstr v_cmpx_nle_f32
syntax keyword asmInstr v_cmpx_nle_f64
syntax keyword asmInstr v_cmpx_nlg_f16
syntax keyword asmInstr v_cmpx_nlg_f32
syntax keyword asmInstr v_cmpx_nlg_f64
syntax keyword asmInstr v_cmpx_nlt_f16
syntax keyword asmInstr v_cmpx_nlt_f32
syntax keyword asmInstr v_cmpx_nlt_f64
syntax keyword asmInstr v_cmpx_o_f16
syntax keyword asmInstr v_cmpx_o_f32
syntax keyword asmInstr v_cmpx_o_f64
syntax keyword asmInstr v_cmpx_t_f16
syntax keyword asmInstr v_cmpx_t_f32
syntax keyword asmInstr v_cmpx_t_f64
syntax keyword asmInstr v_cmpx_t_i16
syntax keyword asmInstr v_cmpx_t_i32
syntax keyword asmInstr v_cmpx_t_i64
syntax keyword asmInstr v_cmpx_t_u16
syntax keyword asmInstr v_cmpx_t_u32
syntax keyword asmInstr v_cmpx_t_u64
syntax keyword asmInstr v_cmpx_tru_f16
syntax keyword asmInstr v_cmpx_tru_f32
syntax keyword asmInstr v_cmpx_tru_f64
syntax keyword asmInstr v_cmpx_tru_i16
syntax keyword asmInstr v_cmpx_tru_i32
syntax keyword asmInstr v_cmpx_tru_i64
syntax keyword asmInstr v_cmpx_tru_u16
syntax keyword asmInstr v_cmpx_tru_u32
syntax keyword asmInstr v_cmpx_tru_u64
syntax keyword asmInstr v_cmpx_u_f16
syntax keyword asmInstr v_cmpx_u_f32
syntax keyword asmInstr v_cmpx_u_f64
syntax keyword asmInstr v_cndmask_b32
syntax keyword asmInstr v_cos_f16
syntax keyword asmInstr v_cos_f32
syntax keyword asmInstr v_cubeid_f32
syntax keyword asmInstr v_cubema_f32
syntax keyword asmInstr v_cubesc_f32
syntax keyword asmInstr v_cubetc_f32
syntax keyword asmInstr v_cvt_f16_f32
syntax keyword asmInstr v_cvt_f16_i16
syntax keyword asmInstr v_cvt_f16_u16
syntax keyword asmInstr v_cvt_f32_f16
syntax keyword asmInstr v_cvt_f32_f64
syntax keyword asmInstr v_cvt_f32_i32
syntax keyword asmInstr v_cvt_f32_u32
syntax keyword asmInstr v_cvt_f32_ubyte0
syntax keyword asmInstr v_cvt_f32_ubyte1
syntax keyword asmInstr v_cvt_f32_ubyte2
syntax keyword asmInstr v_cvt_f32_ubyte3
syntax keyword asmInstr v_cvt_f64_f32
syntax keyword asmInstr v_cvt_f64_i32
syntax keyword asmInstr v_cvt_f64_u32
syntax keyword asmInstr v_cvt_flr_i32_f32
syntax keyword asmInstr v_cvt_i16_f16
syntax keyword asmInstr v_cvt_i32_f32
syntax keyword asmInstr v_cvt_i32_f64
syntax keyword asmInstr v_cvt_norm_i16_f16
syntax keyword asmInstr v_cvt_norm_u16_f16
syntax keyword asmInstr v_cvt_off_f32_i4
syntax keyword asmInstr v_cvt_pk_i16_i32
syntax keyword asmInstr v_cvt_pk_u16_u32
syntax keyword asmInstr v_cvt_pk_u8_f32
syntax keyword asmInstr v_cvt_pkaccum_u8_f32
syntax keyword asmInstr v_cvt_pknorm_i16_f16
syntax keyword asmInstr v_cvt_pknorm_i16_f32
syntax keyword asmInstr v_cvt_pknorm_u16_f16
syntax keyword asmInstr v_cvt_pknorm_u16_f32
syntax keyword asmInstr v_cvt_pkrtz_f16_f32
syntax keyword asmInstr v_cvt_rpi_i32_f32
syntax keyword asmInstr v_cvt_u16_f16
syntax keyword asmInstr v_cvt_u32_f32
syntax keyword asmInstr v_cvt_u32_f64
syntax keyword asmInstr v_div_fixup_f16
syntax keyword asmInstr v_div_fixup_f32
syntax keyword asmInstr v_div_fixup_f64
syntax keyword asmInstr v_div_fixup_legacy_f16
syntax keyword asmInstr v_div_fmas_f32
syntax keyword asmInstr v_div_fmas_f64
syntax keyword asmInstr v_div_scale_f32
syntax keyword asmInstr v_div_scale_f64
syntax keyword asmInstr v_dot2_f32_f16
syntax keyword asmInstr v_dot2_i32_i16
syntax keyword asmInstr v_dot2_u32_u16
syntax keyword asmInstr v_dot4_i32_i8
syntax keyword asmInstr v_dot4_u32_u8
syntax keyword asmInstr v_dot8_i32_i4
syntax keyword asmInstr v_dot8_u32_u4
syntax keyword asmInstr v_exp_f16
syntax keyword asmInstr v_exp_f32
syntax keyword asmInstr v_exp_legacy_f32
syntax keyword asmInstr v_ffbh_i32
syntax keyword asmInstr v_ffbh_u32
syntax keyword asmInstr v_ffbl_b32
syntax keyword asmInstr v_floor_f16
syntax keyword asmInstr v_floor_f32
syntax keyword asmInstr v_floor_f64
syntax keyword asmInstr v_fma_f16
syntax keyword asmInstr v_fma_f32
syntax keyword asmInstr v_fma_f64
syntax keyword asmInstr v_fma_legacy_f16
syntax keyword asmInstr v_fmac_f32
syntax keyword asmInstr v_fract_f16
syntax keyword asmInstr v_fract_f32
syntax keyword asmInstr v_fract_f64
syntax keyword asmInstr v_frexp_exp_i16_f16
syntax keyword asmInstr v_frexp_exp_i32_f32
syntax keyword asmInstr v_frexp_exp_i32_f64
syntax keyword asmInstr v_frexp_mant_f16
syntax keyword asmInstr v_frexp_mant_f32
syntax keyword asmInstr v_frexp_mant_f64
syntax keyword asmInstr v_interp_mov_f32
syntax keyword asmInstr v_interp_p1_f32
syntax keyword asmInstr v_interp_p1ll_f16
syntax keyword asmInstr v_interp_p1lv_f16
syntax keyword asmInstr v_interp_p2_f16
syntax keyword asmInstr v_interp_p2_f32
syntax keyword asmInstr v_interp_p2_legacy_f16
syntax keyword asmInstr v_ldexp_f16
syntax keyword asmInstr v_ldexp_f32
syntax keyword asmInstr v_ldexp_f64
syntax keyword asmInstr v_lerp_u8
syntax keyword asmInstr v_log_clamp_f32
syntax keyword asmInstr v_log_f16
syntax keyword asmInstr v_log_f32
syntax keyword asmInstr v_log_legacy_f32
syntax keyword asmInstr v_lshl_add_u32
syntax keyword asmInstr v_lshl_b32
syntax keyword asmInstr v_lshl_b64
syntax keyword asmInstr v_lshl_or_b32
syntax keyword asmInstr v_lshlrev_b16
syntax keyword asmInstr v_lshlrev_b32
syntax keyword asmInstr v_lshlrev_b64
syntax keyword asmInstr v_lshr_b32
syntax keyword asmInstr v_lshr_b64
syntax keyword asmInstr v_lshrrev_b16
syntax keyword asmInstr v_lshrrev_b32
syntax keyword asmInstr v_lshrrev_b64
syntax keyword asmInstr v_mac_f16
syntax keyword asmInstr v_mac_f32
syntax keyword asmInstr v_mac_legacy_f32
syntax keyword asmInstr v_mad_f16
syntax keyword asmInstr v_mad_f32
syntax keyword asmInstr v_mad_i16
syntax keyword asmInstr v_mad_i32_i16
syntax keyword asmInstr v_mad_i32_i24
syntax keyword asmInstr v_mad_i64_i32
syntax keyword asmInstr v_mad_legacy_f16
syntax keyword asmInstr v_mad_legacy_f32
syntax keyword asmInstr v_mad_legacy_i16
syntax keyword asmInstr v_mad_legacy_u16
syntax keyword asmInstr v_mad_mix_f32
syntax keyword asmInstr v_mad_mixhi_f16
syntax keyword asmInstr v_mad_mixlo_f16
syntax keyword asmInstr v_mad_u16
syntax keyword asmInstr v_mad_u32_u16
syntax keyword asmInstr v_mad_u32_u24
syntax keyword asmInstr v_mad_u64_u32
syntax keyword asmInstr v_madak_f16
syntax keyword asmInstr v_madak_f32
syntax keyword asmInstr v_madmk_f16
syntax keyword asmInstr v_madmk_f32
syntax keyword asmInstr v_max3_f16
syntax keyword asmInstr v_max3_f32
syntax keyword asmInstr v_max3_i16
syntax keyword asmInstr v_max3_i32
syntax keyword asmInstr v_max3_u16
syntax keyword asmInstr v_max3_u32
syntax keyword asmInstr v_max_f16
syntax keyword asmInstr v_max_f32
syntax keyword asmInstr v_max_f64
syntax keyword asmInstr v_max_i16
syntax keyword asmInstr v_max_i32
syntax keyword asmInstr v_max_legacy_f32
syntax keyword asmInstr v_max_u16
syntax keyword asmInstr v_max_u32
syntax keyword asmInstr v_mbcnt_hi_u32_b32
syntax keyword asmInstr v_mbcnt_lo_u32_b32
syntax keyword asmInstr v_med3_f16
syntax keyword asmInstr v_med3_f32
syntax keyword asmInstr v_med3_i16
syntax keyword asmInstr v_med3_i32
syntax keyword asmInstr v_med3_u16
syntax keyword asmInstr v_med3_u32
syntax keyword asmInstr v_min3_f16
syntax keyword asmInstr v_min3_f32
syntax keyword asmInstr v_min3_i16
syntax keyword asmInstr v_min3_i32
syntax keyword asmInstr v_min3_u16
syntax keyword asmInstr v_min3_u32
syntax keyword asmInstr v_min_f16
syntax keyword asmInstr v_min_f32
syntax keyword asmInstr v_min_f64
syntax keyword asmInstr v_min_i16
syntax keyword asmInstr v_min_i32
syntax keyword asmInstr v_min_legacy_f32
syntax keyword asmInstr v_min_u16
syntax keyword asmInstr v_min_u32
syntax keyword asmInstr v_mov_b32
syntax keyword asmInstr v_mov_fed_b32
syntax keyword asmInstr v_mov_prsv_b32
syntax keyword asmInstr v_movreld_b32
syntax keyword asmInstr v_movrels_b32
syntax keyword asmInstr v_movrelsd_b32
syntax keyword asmInstr v_mqsad_pk_u16_u8
syntax keyword asmInstr v_mqsad_u32_u8
syntax keyword asmInstr v_mqsad_u8
syntax keyword asmInstr v_msad_u8
syntax keyword asmInstr v_mul_f16
syntax keyword asmInstr v_mul_f32
syntax keyword asmInstr v_mul_f64
syntax keyword asmInstr v_mul_hi_i32
syntax keyword asmInstr v_mul_hi_i32_i24
syntax keyword asmInstr v_mul_hi_u32
syntax keyword asmInstr v_mul_hi_u32_u24
syntax keyword asmInstr v_mul_i32_i24
syntax keyword asmInstr v_mul_legacy_f32
syntax keyword asmInstr v_mul_lo_i32
syntax keyword asmInstr v_mul_lo_u16
syntax keyword asmInstr v_mul_lo_u32
syntax keyword asmInstr v_mul_u32_u24
syntax keyword asmInstr v_mullit_f32
syntax keyword asmInstr v_nop
syntax keyword asmInstr v_not_b32
syntax keyword asmInstr v_or3_b32
syntax keyword asmInstr v_or_b32
syntax keyword asmInstr v_pack_b32_f16
syntax keyword asmInstr v_perm_b32
syntax keyword asmInstr v_pk_add_f16
syntax keyword asmInstr v_pk_add_i16
syntax keyword asmInstr v_pk_add_u16
syntax keyword asmInstr v_pk_ashrrev_i16
syntax keyword asmInstr v_pk_fma_f16
syntax keyword asmInstr v_pk_lshlrev_b16
syntax keyword asmInstr v_pk_lshrrev_b16
syntax keyword asmInstr v_pk_mad_i16
syntax keyword asmInstr v_pk_mad_u16
syntax keyword asmInstr v_pk_max_f16
syntax keyword asmInstr v_pk_max_i16
syntax keyword asmInstr v_pk_max_u16
syntax keyword asmInstr v_pk_min_f16
syntax keyword asmInstr v_pk_min_i16
syntax keyword asmInstr v_pk_min_u16
syntax keyword asmInstr v_pk_mul_f16
syntax keyword asmInstr v_pk_mul_lo_u16
syntax keyword asmInstr v_pk_sub_i16
syntax keyword asmInstr v_pk_sub_u16
syntax keyword asmInstr v_qsad_pk_u16_u8
syntax keyword asmInstr v_qsad_u8
syntax keyword asmInstr v_rcp_clamp_f32
syntax keyword asmInstr v_rcp_clamp_f64
syntax keyword asmInstr v_rcp_f16
syntax keyword asmInstr v_rcp_f32
syntax keyword asmInstr v_rcp_f64
syntax keyword asmInstr v_rcp_iflag_f32
syntax keyword asmInstr v_rcp_legacy_f32
syntax keyword asmInstr v_readfirstlane_b32
syntax keyword asmInstr v_readlane_b32
syntax keyword asmInstr v_readlane_regrd_b32
syntax keyword asmInstr v_rndne_f16
syntax keyword asmInstr v_rndne_f32
syntax keyword asmInstr v_rndne_f64
syntax keyword asmInstr v_rsq_clamp_f32
syntax keyword asmInstr v_rsq_clamp_f64
syntax keyword asmInstr v_rsq_f16
syntax keyword asmInstr v_rsq_f32
syntax keyword asmInstr v_rsq_f64
syntax keyword asmInstr v_rsq_legacy_f32
syntax keyword asmInstr v_sad_hi_u8
syntax keyword asmInstr v_sad_u16
syntax keyword asmInstr v_sad_u32
syntax keyword asmInstr v_sad_u8
syntax keyword asmInstr v_sat_pk_u8_i16
syntax keyword asmInstr v_screen_partition_4se_b32
syntax keyword asmInstr v_sin_f16
syntax keyword asmInstr v_sin_f32
syntax keyword asmInstr v_sqrt_f16
syntax keyword asmInstr v_sqrt_f32
syntax keyword asmInstr v_sqrt_f64
syntax keyword asmInstr v_sub_co_u32
syntax keyword asmInstr v_sub_f16
syntax keyword asmInstr v_sub_f32
syntax keyword asmInstr v_sub_i16
syntax keyword asmInstr v_sub_i32
syntax keyword asmInstr v_sub_u16
syntax keyword asmInstr v_sub_u32
syntax keyword asmInstr v_subb_co_u32
syntax keyword asmInstr v_subb_u32
syntax keyword asmInstr v_subbrev_co_u32
syntax keyword asmInstr v_subbrev_u32
syntax keyword asmInstr v_subrev_co_u32
syntax keyword asmInstr v_subrev_f16
syntax keyword asmInstr v_subrev_f32
syntax keyword asmInstr v_subrev_i32
syntax keyword asmInstr v_subrev_u16
syntax keyword asmInstr v_subrev_u32
syntax keyword asmInstr v_swap_b32
syntax keyword asmInstr v_trig_preop_f64
syntax keyword asmInstr v_trunc_f16
syntax keyword asmInstr v_trunc_f32
syntax keyword asmInstr v_trunc_f64
syntax keyword asmInstr v_writelane_b32
syntax keyword asmInstr v_writelane_regwr_b32
syntax keyword asmInstr v_xad_u32
syntax keyword asmInstr v_xnor_b32
syntax keyword asmInstr v_xor_b32

highlight default link asmCondit PreCondit
highlight default link asmMacro Macro
highlight default link asmInclude Include
highlight default link asmInteger Number
highlight default link asmFloat Float
highlight default link asmChar Character
highlight default link asmString String
highlight default link asmVar Identifier
highlight default link asmComment Comment
highlight default link asmInstr Statement
highlight default link asmOperator Identifier
highlight default link asmRegister Identifier
highlight default link asmPseudoOps Special

let b:current_syntax = "clrx"

let &cpo = s:cpo_save
unlet s:cpo_save

" vim: ts=8
